==> haskell-fingertree-0.1.6.2-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fingertree
version:              0.1.6.2
visibility:           public
id:                   fingertree-0.1.6.2-Ls26iZ5yxaMC5VMnUeYOwm
key:                  fingertree-0.1.6.2-Ls26iZ5yxaMC5VMnUeYOwm
license:              BSD-3-Clause
copyright:            (c) 2006 Ross Paterson, Ralf Hinze
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
synopsis:             Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of

    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <https://staff.city.ac.uk/~ross/papers/FingerTree.html>

    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.

category:             Data Structures
abi:                  2e7dbdab7f659306e5df803999104bf1
exposed:              True
exposed-modules:
    Data.FingerTree Data.IntervalMap.FingerTree
    Data.PriorityQueue.FingerTree

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fingertree-0.1.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fingertree-0.1.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fingertree-0.1.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fingertree
hs-libraries:         HSfingertree-0.1.6.2-Ls26iZ5yxaMC5VMnUeYOwm
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-fingertree/html/fingertree.haddock
haddock-html:         /usr/share/doc/haskell-fingertree/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fingertree-0.1.6.2-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fingertree
version:              0.1.6.2
visibility:           public
id:                   fingertree-0.1.6.2-sfsUmtIDV1A59av3dM71Y
key:                  fingertree-0.1.6.2-sfsUmtIDV1A59av3dM71Y
license:              BSD-3-Clause
copyright:            (c) 2006 Ross Paterson, Ralf Hinze
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
synopsis:             Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of

    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <https://staff.city.ac.uk/~ross/papers/FingerTree.html>

    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.

category:             Data Structures
abi:                  940667bce742093b6e279aac8785f9cf
exposed:              True
exposed-modules:
    Data.FingerTree Data.IntervalMap.FingerTree
    Data.PriorityQueue.FingerTree

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fingertree-0.1.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fingertree-0.1.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fingertree-0.1.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fingertree
hs-libraries:         HSfingertree-0.1.6.2-sfsUmtIDV1A59av3dM71Y
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-fingertree/html/fingertree.haddock
haddock-html:         /usr/share/doc/haskell-fingertree/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
